[![Github Test](https://github.com/four-velocity/kyotsu/workflows/Test/badge.svg?event=push&branch=master&style=flat-square)]()
[![Coverage](https://coverage-badge.samuelcolvin.workers.dev/four-velocity/kyotsu.svg?style=flat-square)]()
[![PyPI - Version](https://img.shields.io/pypi/v/kyotsu)](https://pypi.org/project/kyotsu/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kyotsu)](https://pypi.org/project/kyotsu/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Built with Material for MkDocs](https://img.shields.io/badge/Material_for_MkDocs-526CFE?logo=MaterialForMkDocs&logoColor=white)](https://squidfunk.github.io/mkdocs-material/)

# Kyōtsū 共通
A package with common logic and use cases used as foundation for microservices.
